All of lore.kernel.org
 help / color / mirror / Atom feed
From: Bob Liu <lliubbo@gmail.com>
To: akpm@linux-foundation.org
Cc: laijs@cn.fujitsu.com, wency@cn.fujitsu.com, jiang.liu@huawei.com,
	isimatu.yasuaki@jp.fujitsu.com, linux-mm@kvack.org,
	Bob Liu <lliubbo@gmail.com>
Subject: [PATCH] mm: memory_hotplug: fix build error
Date: Tue, 11 Dec 2012 16:05:58 +0800	[thread overview]
Message-ID: <1355213158-4955-1-git-send-email-lliubbo@gmail.com> (raw)

Fix below build error(and comment):
mm/memory_hotplug.c:646:14: error: ‘ZONE_HIGH’ undeclared (first use in this
function)
mm/memory_hotplug.c:646:14: note: each undeclared identifier is reported
only once for each function it appears in
make[1]: *** [mm/memory_hotplug.o] Error 1

Signed-off-by: Bob Liu <lliubbo@gmail.com>
---
 mm/memory_hotplug.c |    6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/mm/memory_hotplug.c b/mm/memory_hotplug.c
index ea71d0d..9e97530 100644
--- a/mm/memory_hotplug.c
+++ b/mm/memory_hotplug.c
@@ -636,14 +636,14 @@ static void node_states_check_changes_online(unsigned long nr_pages,
 #ifdef CONFIG_HIGHMEM
 	/*
 	 * If we have movable node, node_states[N_HIGH_MEMORY]
 	 * contains nodes which have zones of 0...ZONE_HIGH,
 	 * set zone_last to ZONE_HIGH.
 	 *
 	 * If we don't have movable node, node_states[N_NORMAL_MEMORY]
 	 * contains nodes which have zones of 0...ZONE_MOVABLE,
 	 * set zone_last to ZONE_MOVABLE.
 	 */
-	zone_last = ZONE_HIGH;
+	zone_last = ZONE_HIGHMEM;
 	if (N_MEMORY == N_HIGH_MEMORY)
 		zone_last = ZONE_MOVABLE;
 
@@ -636,14 +636,14 @@ static void node_states_check_changes_online(unsigned long nr_pages,
 	/*
 	 * If we have movable node, node_states[N_HIGH_MEMORY]
-	 * contains nodes which have zones of 0...ZONE_HIGH,
-	 * set zone_last to ZONE_HIGH.
+	 * contains nodes which have zones of 0...ZONE_HIGHMEM,
+	 * set zone_last to ZONE_HIGHMEM.
 	 *
 	 * If we don't have movable node, node_states[N_NORMAL_MEMORY]
-- 
1.7.9.5


--
To unsubscribe, send a message with 'unsubscribe linux-mm' in
the body to majordomo@kvack.org.  For more info on Linux MM,
see: http://www.linux-mm.org/ .
Don't email: <a href=mailto:"dont@kvack.org"> email@kvack.org </a>

             reply	other threads:[~2012-12-11  8:06 UTC|newest]

Thread overview: 3+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2012-12-11  8:05 Bob Liu [this message]
2012-12-11  8:21 ` [PATCH] mm: memory_hotplug: fix build error Andrew Morton
2012-12-11  8:41   ` Bob Liu

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1355213158-4955-1-git-send-email-lliubbo@gmail.com \
    --to=lliubbo@gmail.com \
    --cc=akpm@linux-foundation.org \
    --cc=isimatu.yasuaki@jp.fujitsu.com \
    --cc=jiang.liu@huawei.com \
    --cc=laijs@cn.fujitsu.com \
    --cc=linux-mm@kvack.org \
    --cc=wency@cn.fujitsu.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.